<div align="center">

# QMTools

Quantum Mechanics Tools for Python.

<img src="https://img.shields.io/static/v1?label=version&message=0.1-beta0&color=ae35ea&style=flat"/>
&nbsp
<img src="https://img.shields.io/static/v1?label=license&message=GPLv3&color=ae35ea&style=flat"/>

</div>

## Goal

Motivated by the work and computational activities of the Quantum Physics Fundamentals course, I decided, even as a personal challenge, to create a didactic package for the study of this course. Therefore, the material was thought to leave everything well documented and straight to the point. In this way, the library has basic functions for those who want to go quick and dirty, but also allow the most curious to explore the possibilities.

## Requirements

- **Python**: >=3.9 (should work in >=3.6, but still need some tests)
- **Libraries**: NumPy, Scipy, Plotly (optional) 

## Installation

The **qmtools** package is hosted on PyPi. Thus, it is possible to install this library in  virtual environment using `pip` (use the appropriate command for your system):

```
~ pip install qmtools
~ pip3 install qmtools
~ python -m pip install qmtools
~ python3 -m pip install qmtools
```

## Licence

The licence for this project is GPLv3 which means, in short, that the code is open source and those who are going to use it must leave their projects open source as well.